@@ -322,12 +322,13 @@ check_internet = function(host=NULL) {
 # download and read excel file from website
 #' @importFrom readxl read_excel
 # @importFrom utils download.file
-#' @importFrom curl curl_download new_handle 
+#' @importFrom curl curl_download new_handle  handle_setheaders
 load_read_xl = function(url, handle=new_handle()) {
     temp = tempfile()
-    on.exit(unlink(temp))
+    on.exit(unlink(temp))  
+    
+    curl_download(url, destfile = temp, handle = handle) 
     
-    curl_download(url, destfile = temp, handle = handle)
     dat = read_excel(temp)
     
     return(setDT(dat))
@@ -499,7 +500,7 @@ load_dat_loop = function(symbol, func, args=list(), print_step=0, sleep = 0, ...
         datmp = try(do.call(func, c(syb_i, args)), silent = TRUE)
         dt_list[[syb_i]] = datmp[]
         # sleep for 1s
-        if (sleep > 0) Sys.sleep(abs(rnorm(1, mean=sleep)))
+        if (sleep > 0 && !is.null(sleep)) Sys.sleep(abs(rnorm(1, mean=sleep)))
     }
     return(dt_list[])
 }
