@@ -13,11 +13,58 @@ date_ft1y = function(from, to) {
     return(ft)
 }
 
-load_data_chinamoney = function(url, ft) {
+#' @importFrom httr use_proxy add_headers POST write_disk
+load_read_xl_chinamoney = function(url) {
+    temp = tempfile()
+    on.exit(unlink(temp))  
+    
+    # proxy
+    proxy <- use_proxy(url = "127.0.0.1", port = 1080)  # 代理地址和端口与浏览器一致
+    
+    # header
+    headers <- add_headers(
+        "Host" = "www.chinamoney.com.cn",
+        "User-Agent" = "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/138.0.0.0 Safari/537.36",
+        "Accept" = "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7",
+        "Accept-Encoding" = "gzip, deflate, br, zstd",
+        "Accept-Language" = "en-US,en;q=0.9",
+        "Cache-Control" = "max-age=0",
+        "Connection" = "keep-alive",
+        "Content-Type" = "application/x-www-form-urlencoded",
+        "Content-Length" = "0",
+        "Origin" = "https://www.chinamoney.com.cn",
+        "Referer" = "https://www.chinamoney.com.cn/chinese/bkrmbidx/",
+        "Cookie" = "_ulta_id.CM-Prod.e9dc=84f728c7be450344; AlteonP10=AN1PXyw/F6y9ZXM1BXdSQw$$; lss=c21ab7243ea1585f3bf81b2856caa228; _ulta_ses.CM-Prod.e9dc=b710b0b4d488916c; isLogin=0",
+        "sec-ch-ua" = "\"Not)A;Brand\";v=\"8\", \"Chromium\";v=\"138\", \"Google Chrome\";v=\"138\"",
+        "sec-ch-ua-mobile" = "?0",
+        "sec-ch-ua-platform" = "\"macOS\"",
+        "Sec-Fetch-Dest" = "document",
+        "Sec-Fetch-Mode" = "navigate",
+        "Sec-Fetch-Site" = "same-origin",
+        "Sec-Fetch-User" = "?1",
+        "Upgrade-Insecure-Requests" = "1"
+    )
+    
+    # 6. 使用代理发送POST请求
+    response <- POST(
+        url,
+        proxy, 
+        headers,
+        body = "",
+        encode = "form",
+        write_disk(temp, overwrite = TRUE)#,
+        # verbose()
+    )
+    dat = read_excel(temp)
+    return(setDT(dat))
+}
+
+load_data_chinamoney = function(url, ft) { 
+        
     datlst = lapply(
         split(ft, by = 'f'),
         function(x) {
-            dat = load_read_xl(sprintf(url, x$f, x$t))
+            dat = load_read_xl_chinamoney(sprintf(url, x$f, x$t))
             
             setnames(dat, names(dat)[1], 'date')
             return(dat)
@@ -95,7 +142,8 @@ md_cnlpr = function(date_range = 'max', from=NULL, to=Sys.Date(), ...) {
     from = check_from(date_range, from, to, default_from = "1997-01-01", default_date_range = '3y')
     
     # loan prime rate
-    dtlpr = load_read_xl(sprintf('https://www.chinamoney.com.cn/dqs/rest/cm-u-bk-currency/LprHisExcel?lang=CN&strStartDate=%s&strEndDate=%s', data.table(f=from, t=to)$f, to))
+    # https://www.chinamoney.com.cn/dqs/rest/cm-u-bk-currency/LprHisExcel?lang=CN&strStartDate=2024-08-04&strEndDate=2025-08-03
+    dtlpr = load_read_xl_chinamoney(sprintf('https://www.chinamoney.com.cn/dqs/rest/cm-u-bk-currency/LprHisExcel?lang=CN&strStartDate=%s&strEndDate=%s', from, to))
     setnames(dtlpr, c('date', "cn1ylpr", "cn5ylpr"))
     dtlpr = dtlpr[, `:=`(
         date = as.Date(date), 
@@ -108,8 +156,11 @@ md_cnlpr = function(date_range = 'max', from=NULL, to=Sys.Date(), ...) {
     setnames(dtpr, c('date', 'cn1ydpr', 'cn1ylpr'))
     # https://www.chinamoney.com.cn/dqs/rest/cm-u-bk-currency/LprHisExcel?lang=CN&strStartDate=2023-03-24&strEndDate=2024-03-23
     
-    
-    dat = md_moneycn_widelong(rbind(dtlpr, dtpr, fill = TRUE))[!is.na(value)][order(symbol, date)][]
+    datlst = list()
+    if (nrow(dtlpr) > 0) datlst$lpr = dtlpr
+    if (nrow(dtpr) > 0) datlst$ppr = dtpr
+        
+    dat = md_moneycn_widelong(rbindlist(datlst, fill = TRUE))[!is.na(value)][order(symbol, date)][]
     return(dat[])
 }
 
@@ -149,6 +200,7 @@ md_cnrmbx = function(date_range = '3y', from=NULL, to=Sys.Date(), ...) {
     to = check_to(to)
     from = check_from(date_range, from, to, default_from = "2015-01-01", default_date_range = '3y')
     
+    # https://www.chinamoney.com.cn/dqs/rest/cm-u-bk-fx/RmbIdxHisExcel?lang=CN&startDate=2024-08-04&endDate=2025-08-03&t=1754190956083
     ## download data
     dat = load_data_chinamoney(paste0('https://www.chinamoney.com.cn/dqs/rest/cm-u-bk-fx/RmbIdxHisExcel?lang=CN&startDate=%s&endDate=%s&t=', date_num(Sys.time(), 'ms')), date_ft1y(from, to))
     
