@@ -92,6 +92,7 @@ pq1_performance = function(dt1, Ra, Rb=NULL, perf_fun, col_date='date', ...) {
 #' @param ... additional parameters, the arguments used in `PerformanceAnalytics` functions.
 #' 
 #' @examples  
+#' \dontrun{
 #' library(pedquant) 
 #' library(data.table)
 #' 
@@ -113,6 +114,7 @@ pq1_performance = function(dt1, Ra, Rb=NULL, perf_fun, col_date='date', ...) {
 #' # claculate table.CAPM metrics
 #' perf_capm = pq_performance(datRaRb, Ra = 'Ra', Rb = 'Rb', perf_fun = 'table.CAPM')
 #' rbindlist(perf_capm, idcol = 'symbol')
+#' }
 #' 
 #' @export
 #' 
@@ -132,11 +134,13 @@ pq_performance = function(dt, Ra, Rb=NULL, perf_fun, ...) {
 
 
 pq_perfeva = function(dt, x, orders, addti=NULL, init_fund=NULL) {
-    tid = type = stc = bto = NULL 
+    tid = bs = s = b = NULL 
     
-    if (!('volumes' %in% names(orders))) {
+    if (!('quantity' %in% names(orders))) {
         orders = odr_addvol(orders)
     }
+    orders = check_odr(orders)
+    
     dt = pq_portfolio(dt, x=x, orders=orders, cols_keep = 'all', init_fund = init_fund)
     addti = c(addti, list(cumreturns=list(), portfolio=list()))
     
@@ -147,9 +151,9 @@ pq_perfeva = function(dt, x, orders, addti=NULL, init_fund=NULL) {
     ) )
     
     # orders summary
-    odr_summary = dcast(copy(orders)[, tid := cumsum(type == 'bto') ], 'tid ~ type', value.var = 'prices')
+    odr_summary = dcast(copy(orders)[, tid := cumsum(bs == 'b') ], 'tid ~ bs', value.var = 'prices')
     # winning ratio
-    wr = odr_summary[, round(mean(stc>bto, na.rm = TRUE),3)*100]
+    wr = odr_summary[, round(mean(s>b, na.rm = TRUE),3)*100]
     print(list(winning_ratio = wr))
     
     return(e)
