@@ -300,7 +300,7 @@ pp_base = function(dt, x = 'date', h='100%', yb=NULL, yvol = NULL, ...) {
     
     # volume line
     if (!is.null(yvol) && !all(is.na(dt[[yvol]]))) { 
-        yvolmax = ceiling2(quantile(dt[[yvol]], 0.75) + IQR(dt[[yvol]])*3) * 5
+        yvolmax = ceiling2(quantile(dt[[yvol]], 0.75, na.rm = T) + IQR(dt[[yvol]], na.rm = T)*3) * 5
         
         e = e_line_(e, serie = yvol, legend=TRUE, y_index = 1, symbol='none', color = '#D3D3D3', lineStyle = list(
             width = 1
